==> pytablewriter-0.6.0.tar.gz: pytablewriter-0.6.0/test/test_rst_csv_writer.py <==
# encoding: utf-8

"""
.. codeauthor:: Tsuyoshi Hombashi <gogogo.vm@gmail.com>
"""

from __future__ import absolute_import
import collections

import pytablewriter
import pytest

from .data import header_list
from .data import value_matrix
from .data import value_matrix_with_none
from .data import mix_header_list
from .data import mix_value_matrix


Data = collections.namedtuple("Data", "table indent header value expected")

normal_test_data_list = [
    Data(
        table="",
        indent=0,
        header=header_list,
        value=value_matrix,
        expected=""".. csv-table:: 
    :header: "a", "b", "c", "dd", "e"
    :widths: 1, 5, 3, 3, 4
    
    1, 123.1, "a", 1.0, "1"
    2, 2.2, "bb", 2.2, "2.2"
    3, 3.3, "ccc", 3.0, "cccc"
"""
    ),
    Data(
        table="tablename",
        indent=0,
        header=header_list,
        value=value_matrix,
        expected=""".. csv-table:: tablename
    :header: "a", "b", "c", "dd", "e"
    :widths: 1, 5, 3, 3, 4
    
    1, 123.1, "a", 1.0, "1"
    2, 2.2, "bb", 2.2, "2.2"
    3, 3.3, "ccc", 3.0, "cccc"
"""
    ),
    Data(
        table="",
        indent=1,
        header=header_list,
        value=value_matrix,
        expected="""    .. csv-table:: 
        :header: "a", "b", "c", "dd", "e"
        :widths: 1, 5, 3, 3, 4
        
        1, 123.1, "a", 1.0, "1"
        2, 2.2, "bb", 2.2, "2.2"
        3, 3.3, "ccc", 3.0, "cccc"
"""
    ),
    Data(
        table="table name",
        indent=0,
        header=header_list,
        value=value_matrix_with_none,
        expected=""".. csv-table:: table name
    :header: "a", "b", "c", "dd", "e"
    :widths: 1, 3, 3, 3, 4
    
    1, , "a", 1.0, 
    , 2.2, , 2.2, "2.2"
    3, 3.3, "ccc", , "cccc"
    , , , , 
"""
    ),
    Data(
        table="table name",
        indent=0,
        header=mix_header_list,
        value=mix_value_matrix,
        expected=""".. csv-table:: table name
    :header: "i", "f", "c", "if", "ifc", "bool", "inf", "nan", "mix_num", "time"
    :widths: 1, 4, 4, 4, 3, 5, 3, 3, 7, 24
    
    1, 1.10, "aa", 1.0, "1", True, inf, nan, 1.0, "2017-01-01 00:00:00"
    2, 2.20, "bbb", 2.2, "2.2", False, inf, nan, inf, "2017-01-02 03:04:05+0900"
    3, 3.33, "cccc", -3.0, "ccc", True, inf, nan, nan, "2017-01-01 00:00:00"
"""
    ),
]

exception_test_data_list = [
    Data(
        table="",
        indent=normal_test_data_list[0].indent,
        header=[],
        value=[],
        expected=pytablewriter.EmptyHeaderError
    ),
    Data(
        table="",
        indent=normal_test_data_list[0].indent,
        header=[],
        value=normal_test_data_list[0].value,
        expected=pytablewriter.EmptyHeaderError
    ),
    Data(
        table="",
        indent=normal_test_data_list[0].indent,
        header=None,
        value=normal_test_data_list[0].value,
        expected=pytablewriter.EmptyHeaderError
    ),
    Data(
        table="",
        indent=normal_test_data_list[0].indent,
        header=normal_test_data_list[0].header,
        value=[],
        expected=pytablewriter.EmptyValueError
    ),
    Data(
        table="",
        indent=normal_test_data_list[0].indent,
        header=normal_test_data_list[0].header,
        value=None,
        expected=pytablewriter.EmptyValueError,
    ),
]

table_writer_class = pytablewriter.RstCsvTableWriter


class Test_RstCsvTableWriter_write_new_line:

    def test_normal(self, capsys):
        writer = table_writer_class()
        writer.write_null_line()

        out, err = capsys.readouterr()
        assert out == "\n"


class Test_RstCsvTableWriter_write_table:

    @pytest.mark.parametrize(
        ["table", "indent", "header", "value", "expected"],
        [
            [data.table, data.indent, data.header, data.value, data.expected]
            for data in normal_test_data_list
        ]
    )
    def test_normal(self, capsys, table, indent, header, value, expected):
        writer = table_writer_class()
        writer.table_name = table
        writer.set_indent_level(indent)
        writer.header_list = header
        writer.value_matrix = value
        writer.write_table()

        out, err = capsys.readouterr()
        assert out == expected

    @pytest.mark.parametrize(
        ["table", "indent", "header", "value", "expected"],
        [
            [data.table, data.indent, data.header, data.value, data.expected]
            for data in exception_test_data_list
        ]
    )
    def test_exception(self, capsys, table, indent, header, value, expected):
        writer = table_writer_class()
        writer.table_name = table
        writer.set_indent_level(indent)
        writer.header_list = header
        writer.value_matrix = value

        with pytest.raises(expected):
            writer.write_table()

==> pytablewriter-0.7.0.tar.gz: pytablewriter-0.7.0/test/test_rst_csv_writer.py <==
# encoding: utf-8

"""
.. codeauthor:: Tsuyoshi Hombashi <gogogo.vm@gmail.com>
"""

from __future__ import absolute_import
import collections

import pytablewriter
import pytest

from .data import header_list
from .data import value_matrix
from .data import value_matrix_with_none
from .data import mix_header_list
from .data import mix_value_matrix


Data = collections.namedtuple("Data", "table indent header value expected")

normal_test_data_list = [
    Data(
        table="",
        indent=0,
        header=header_list,
        value=value_matrix,
        expected=""".. csv-table:: 
    :header: "a", "b", "c", "dd", "e"
    :widths: 1, 5, 3, 3, 4
    
    1, 123.1, "a", 1.0, "1"
    2, 2.2, "bb", 2.2, "2.2"
    3, 3.3, "ccc", 3.0, "cccc"
"""
    ),
    Data(
        table="",
        indent=0,
        header=header_list,
        value=None,
        expected=""".. csv-table:: 
    :header: "a", "b", "c", "dd", "e"
    :widths: 1, 1, 1, 2, 1
    
"""
    ),
    Data(
        table="tablename",
        indent=0,
        header=header_list,
        value=value_matrix,
        expected=""".. csv-table:: tablename
    :header: "a", "b", "c", "dd", "e"
    :widths: 1, 5, 3, 3, 4
    
    1, 123.1, "a", 1.0, "1"
    2, 2.2, "bb", 2.2, "2.2"
    3, 3.3, "ccc", 3.0, "cccc"
"""
    ),
    Data(
        table="",
        indent=1,
        header=header_list,
        value=value_matrix,
        expected="""    .. csv-table:: 
        :header: "a", "b", "c", "dd", "e"
        :widths: 1, 5, 3, 3, 4
        
        1, 123.1, "a", 1.0, "1"
        2, 2.2, "bb", 2.2, "2.2"
        3, 3.3, "ccc", 3.0, "cccc"
"""
    ),
    Data(
        table="table name",
        indent=0,
        header=header_list,
        value=value_matrix_with_none,
        expected=""".. csv-table:: table name
    :header: "a", "b", "c", "dd", "e"
    :widths: 1, 3, 3, 3, 4
    
    1, , "a", 1.0, 
    , 2.2, , 2.2, "2.2"
    3, 3.3, "ccc", , "cccc"
    , , , , 
"""
    ),
    Data(
        table="table name",
        indent=0,
        header=mix_header_list,
        value=mix_value_matrix,
        expected=""".. csv-table:: table name
    :header: "i", "f", "c", "if", "ifc", "bool", "inf", "nan", "mix_num", "time"
    :widths: 1, 4, 4, 4, 3, 5, 3, 3, 7, 24
    
    1, 1.10, "aa", 1.0, "1", True, inf, nan, 1.0, "2017-01-01 00:00:00"
    2, 2.20, "bbb", 2.2, "2.2", False, inf, nan, inf, "2017-01-02 03:04:05+0900"
    3, 3.33, "cccc", -3.0, "ccc", True, inf, nan, nan, "2017-01-01 00:00:00"
"""
    ),
]

exception_test_data_list = [
    Data(
        table="",
        indent=normal_test_data_list[0].indent,
        header=[],
        value=[],
        expected=pytablewriter.EmptyHeaderError
    ),
    Data(
        table="",
        indent=normal_test_data_list[0].indent,
        header=[],
        value=normal_test_data_list[0].value,
        expected=pytablewriter.EmptyHeaderError
    ),
    Data(
        table="",
        indent=normal_test_data_list[0].indent,
        header=None,
        value=normal_test_data_list[0].value,
        expected=pytablewriter.EmptyHeaderError
    ),
]

table_writer_class = pytablewriter.RstCsvTableWriter


class Test_RstCsvTableWriter_write_new_line:

    def test_normal(self, capsys):
        writer = table_writer_class()
        writer.write_null_line()

        out, _err = capsys.readouterr()
        assert out == "\n"


class Test_RstCsvTableWriter_write_table:

    @pytest.mark.parametrize(
        ["table", "indent", "header", "value", "expected"],
        [
            [data.table, data.indent, data.header, data.value, data.expected]
            for data in normal_test_data_list
        ]
    )
    def test_normal(self, capsys, table, indent, header, value, expected):
        writer = table_writer_class()
        writer.table_name = table
        writer.set_indent_level(indent)
        writer.header_list = header
        writer.value_matrix = value
        writer.write_table()

        out, _err = capsys.readouterr()
        assert out == expected

    @pytest.mark.parametrize(["table", "header", "expected"], [
        [
            "tablename",
            ["ha", "hb", "hc"],
            """.. csv-table:: tablename
    :header: "ha", "hb", "hc"
    :widths: 2, 2, 2
    
    1, 2, 3
    11, 12, 13
    1, 2, 3
    11, 12, 13
    101, 102, 103
    1001, 1002, 1003
""",
        ],
    ])
    def test_normal_multiple(self, capsys, table, header, expected):
        writer = table_writer_class()
        writer.table_name = table
        writer.header_list = header

        writer.is_write_header = True
        writer.is_write_closing_row = False
        writer.write_table()

        writer.is_write_opening_row = False
        writer.is_write_header = False
        writer.value_matrix = [
            [1, 2, 3],
            [11, 12, 13],
        ]
        writer.write_table()
        writer.write_table()

        writer.is_write_closing_row = True
        writer.value_matrix = [
            [101, 102, 103],
            [1001, 1002, 1003],
        ]
        writer.write_table()

        out, _err = capsys.readouterr()
        assert out == expected

    @pytest.mark.parametrize(
        ["table", "indent", "header", "value", "expected"],
        [
            [data.table, data.indent, data.header, data.value, data.expected]
            for data in exception_test_data_list
        ]
    )
    def test_exception(self, capsys, table, indent, header, value, expected):
        writer = table_writer_class()
        writer.table_name = table
        writer.set_indent_level(indent)
        writer.header_list = header
        writer.value_matrix = value

        with pytest.raises(expected):
            writer.write_table()
